@@ -167,18 +167,9 @@ class MultiTypeUnmarshaller(PrimitiveUnmarshaller):
 
 
 class AnyUnmarshaller(MultiTypeUnmarshaller):
-    SCHEMA_TYPES_ORDER = [
-        "object",
-        "array",
-        "boolean",
-        "integer",
-        "number",
-        "string",
-    ]
-
     @property
     def type(self) -> List[str]:
-        return self.SCHEMA_TYPES_ORDER
+        return self.schema_unmarshaller.types_unmarshaller.get_types()
 
 
 class TypesUnmarshaller:
@@ -195,6 +186,9 @@ class TypesUnmarshaller:
         self.default = default
         self.multi = multi
 
+    def get_types(self) -> List[str]:
+        return list(self.unmarshallers.keys())
+
     def get_unmarshaller(
         self,
         schema_type: Optional[Union[Iterable[str], str]],
